Package: enrichit
Title: 'C++' Implementations of Functional Enrichment Analysis
Version: 0.2.1
Authors@R: person(given = "Guangchuang", family = "Yu",
               email = "guangchuangyu@gmail.com", role  = c("aut", "cre"))
Maintainer: Guangchuang Yu <guangchuangyu@gmail.com>
Description: Fast implementations of functional enrichment analysis methods using 'C++' via 'Rcpp'.
    Currently provides Over-Representation Analysis (ORA), Gene Set Enrichment Analysis (GSEA),
    Weighted Enrichment Analysis for ORA and GSEA, Network-based Set Enrichment Analysis (NSEA),
    multi-layer network-based enrichment, and multi-omics integration workflows. Additional
    features include early fusion at the feature level, late fusion at the pathway level,
    multi-omics contribution tracing, topology-aware explanation helpers, Bayesian term
    selection, and extremely fast Random Walk with Restart (RWR) using 'RcppEigen'. The
    enrichment methods build on GSEA by Subramanian et al. (2005)
    <doi:10.1073/pnas.0506580102>, the multilevel strategy derived from 'fgsea'
    by Korotkevich et al. (2021) <doi:10.1101/060012>, and network-based
    enrichment ideas described by Glaab et al. (2012)
    <doi:10.1093/bioinformatics/bts389>.
License: Artistic-2.0
Depends: R (>= 3.5.0)
Imports: Matrix, methods, Rcpp (>= 1.0.10), rlang, stats, yulab.utils
        (> 0.2.1)
LinkingTo: Rcpp, RcppEigen
Suggests: AnnotationDbi, BiasedUrn, clusterProfiler, DOSE, fgsea, gson,
        qvalue, testthat
Encoding: UTF-8
URL: https://yulab-smu.top/biomedical-knowledge-mining-book/
Config/roxygen2/version: 8.0.0
NeedsCompilation: yes
Packaged: 2026-08-04 17:28:59 UTC; HUAWEI
Author: Guangchuang Yu [aut, cre]
Repository: CRAN
Date/Publication: 2026-08-04 18:40:02 UTC
