# Generated by roxygen2: do not edit by hand

S3method("$",enrichResult)
S3method("$",gseaResult)
S3method("[",enrichResult)
S3method("[",gseaResult)
S3method("[[",enrichResult)
S3method("[[",gseaResult)
S3method(as.data.frame,enrichResult)
S3method(as.data.frame,gseaResult)
S3method(dim,enrichResult)
S3method(dim,gseaResult)
S3method(geneID,compareClusterResult)
S3method(geneID,enrichResult)
S3method(geneID,gseaResult)
S3method(geneInCategory,compareClusterResult)
S3method(geneInCategory,enrichResult)
S3method(geneInCategory,gseaResult)
S3method(head,enrichResult)
S3method(head,gseaResult)
S3method(tail,enrichResult)
S3method(tail,gseaResult)
export(EXTID2NAME)
export(aggregate_enrichment)
export(aggregate_omics)
export(bayes_enrich)
export(bayes_summary)
export(classify_omics_pattern)
export(collapse_multilayer_scores)
export(extract_mnsea_subnetwork)
export(geneID)
export(geneInCategory)
export(get_mnsea_contribution)
export(get_omics_contribution)
export(gsea)
export(gseaScores)
export(gsea_gson)
export(gsfilter)
export(harmonize_ids)
export(mnsea)
export(mnsea_gson)
export(nsea)
export(nsea_gson)
export(ora)
export(ora_gson)
export(prepare_multilayer_network)
export(prepare_network)
export(propagate_multilayer)
export(select_features_for_ora)
export(setReadable)
exportClasses(compareClusterResult)
exportClasses(enrichResult)
exportClasses(gseaResult)
exportClasses(mnseaResult)
exportClasses(nseaResult)
exportMethods(show)
exportMethods(summary)
importClassesFrom(methods,data.frame)
importFrom(Matrix,Diagonal)
importFrom(Matrix,colSums)
importFrom(Matrix,rowSums)
importFrom(Matrix,sparseMatrix)
importFrom(Rcpp,sourceCpp)
importFrom(methods,.hasSlot)
importFrom(methods,is)
importFrom(methods,new)
importFrom(methods,show)
importFrom(rlang,check_installed)
importFrom(stats,median)
importFrom(stats,p.adjust)
importFrom(stats,pchisq)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,str)
importFrom(utils,tail)
importFrom(yulab.utils,yulab_msg)
useDynLib(enrichit, .registration = TRUE)
