# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

ora_cpp <- function(gene, universe, gene_sets, gene_set_names) {
    .Call(`_enrichit_ora_cpp`, gene, universe, gene_sets, gene_set_names)
}

gsea_cpp <- function(stats, gene_sets, gene_set_names, nPerm = 1000L, exponent = 1.0, method = "sample", seed = 12345L) {
    .Call(`_enrichit_gsea_cpp`, stats, gene_sets, gene_set_names, nPerm, exponent, method, seed)
}

gsea_adaptive_cpp <- function(stats, gene_sets, gene_set_names, minPerm = 1000L, maxPerm = 100000L, pvalThreshold = 0.1, exponent = 1.0, method = "sample", seed = 12345L) {
    .Call(`_enrichit_gsea_adaptive_cpp`, stats, gene_sets, gene_set_names, minPerm, maxPerm, pvalThreshold, exponent, method, seed)
}

gsea_multilevel_cpp <- function(geneList, gene_sets, gene_set_names, minPerm, maxPerm, pvalThreshold, exponent, method, eps, sampleSize, seed, nPermSimple = 1000L, scoreType = "std") {
    .Call(`_enrichit_gsea_multilevel_cpp`, geneList, gene_sets, gene_set_names, minPerm, maxPerm, pvalThreshold, exponent, method, eps, sampleSize, seed, nPermSimple, scoreType)
}

gsea_scores_cpp <- function(stats, in_set, exponent) {
    .Call(`_enrichit_gsea_scores_cpp`, stats, in_set, exponent)
}

#' Random Walk with Restart using Eigen Sparse Matrix
#'
#' @param A column-normalized sparse matrix
#' @param v initial restart vector
#' @param restart restart probability (e.g., 0.5)
#' @param threshold convergence threshold
#' @param max_iter maximal number of iterations
#' @return list containing stationary probabilities and iterations
#' @noRd
rwr_eigen_cpp <- function(A, v, restart, threshold, max_iter) {
    .Call(`_enrichit_rwr_eigen_cpp`, A, v, restart, threshold, max_iter)
}

