% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/00-AllClasses.R
\docType{class}
\name{mnseaResult-class}
\alias{mnseaResult-class}
\title{Class "mnseaResult"
This class represents the result of multi-layer Network-based Set Enrichment Analysis.}
\description{
Class "mnseaResult"
This class represents the result of multi-layer Network-based Set Enrichment Analysis.
}
\section{Slots}{

\describe{
\item{\code{result}}{enrichment analysis}

\item{\code{organism}}{organism label for the enrichment result}

\item{\code{setType}}{gene set collection type}

\item{\code{geneSets}}{gene sets}

\item{\code{geneList}}{order rank geneList}

\item{\code{keytype}}{ID type of gene}

\item{\code{permScores}}{permutation score matrix inherited from \code{gseaResult}}

\item{\code{gene2Symbol}}{gene ID to symbol mapping}

\item{\code{readable}}{logical flag of gene ID in symbol or not.}

\item{\code{termsim}}{Calculation matrix of termsim.}

\item{\code{method}}{Method of termsim.}

\item{\code{params}}{parameters}

\item{\code{dr}}{dimension reduction result}

\item{\code{multilayer_network}}{prepared multi-layer network object.}

\item{\code{layer_scores}}{list of layer-specific diffusion score vectors.}

\item{\code{collapsed_scores}}{numeric vector used for downstream enrichment.}

\item{\code{layer_weights}}{numeric vector of layer weights.}

\item{\code{coupling_table}}{data.frame of inter-layer couplings.}

\item{\code{mode}}{character, "evidence" or "signed".}

\item{\code{iterations}}{integer, the actual number of iterations RWR took to converge.}

\item{\code{restart_prob}}{numeric, the restart probability used in RWR.}

\item{\code{collapse_method}}{character collapse method used on layer scores.}

\item{\code{target_layer}}{optional layer name used for downstream export.}

\item{\code{output_space}}{character output space of collapsed scores.}

\item{\code{pathway_contribution}}{pathway-by-layer contribution table precomputed for explanation.}

\item{\code{feature_contribution}}{feature-by-layer contribution table precomputed for explanation.}
}}

\author{
Guangchuang Yu \url{https://yulab-smu.top}
}
