% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utilities.R
\name{enrichit_params}
\alias{enrichit_params}
\title{Common parameters for enrichit functions}
\arguments{
\item{geneList}{A named numeric vector of gene statistics (e.g., log fold change), ranked in descending order.}

\item{gene_sets}{A named list of gene sets. Each element is a character vector of genes.}

\item{nPerm}{Number of permutations for p-value calculation (default: 1000).}

\item{exponent}{Weighting exponent for enrichment score (default: 1.0).}

\item{minGSSize}{minimal size of each geneSet for analyzing}

\item{maxGSSize}{maximal size of each geneSet for analyzing}

\item{pvalueCutoff}{P-value cutoff.}

\item{pAdjustMethod}{P-value adjustment method (e.g., "BH").}

\item{verbose}{Logical. Print progress messages.}

\item{gson}{A GSON object containing gene set information.}

\item{method}{Permutation method.}

\item{adaptive}{Logical. Use adaptive permutation.}

\item{minPerm}{Minimum permutations for adaptive mode.}

\item{maxPerm}{Maximum permutations for adaptive mode.}

\item{pvalThreshold}{P-value threshold for early stopping.}
}
\description{
Common parameters for enrichit functions
}
\keyword{internal}
