% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mnsea_contribution.R
\name{get_mnsea_contribution}
\alias{get_mnsea_contribution}
\title{Get cached contribution tables from a \code{mnseaResult}}
\usage{
get_mnsea_contribution(res, pathway_id = NULL, level = c("pathway", "feature"))
}
\arguments{
\item{res}{A \code{mnseaResult} object.}

\item{pathway_id}{Optional pathway ID. If \code{NULL}, returns all pathways for
\code{level = "pathway"} and uses the top pathway for \code{level = "feature"}.}

\item{level}{One of \code{"pathway"} or \code{"feature"}.}
}
\value{
A data.frame containing cached contribution information.
}
\description{
Get cached contribution tables from a \code{mnseaResult}
}
