% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ora_gson.R
\name{ora_gson}
\alias{ora_gson}
\title{ora-gson}
\usage{
ora_gson(
  gene,
  pvalueCutoff,
  pAdjustMethod = "BH",
  universe = NULL,
  weight = NULL,
  minGSSize = 10,
  maxGSSize = 500,
  qvalueCutoff = 0.2,
  gson
)
}
\arguments{
\item{gene}{a vector of entrez gene id.}

\item{pvalueCutoff}{P-value cutoff.}

\item{pAdjustMethod}{P-value adjustment method (e.g., "BH").}

\item{universe}{background genes, default is the intersection of the 'universe' with genes that have annotations.
Users can set \code{options(enrichment_force_universe = TRUE)} to force the 'universe' untouched.}

\item{weight}{A named numeric vector of weights for background genes. If provided, Weighted ORA will be performed.}

\item{minGSSize}{minimal size of each geneSet for analyzing}

\item{maxGSSize}{maximal size of each geneSet for analyzing}

\item{qvalueCutoff}{cutoff of qvalue}

\item{gson}{A GSON object containing gene set information.}
}
\value{
A \code{enrichResult} instance.
}
\description{
interal method for enrichment analysis
}
\details{
using the hypergeometric model
}
\author{
Guangchuang Yu \url{https://yulab-smu.top}
}
\keyword{manip}
