% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_enrich.R
\name{bayes_summary}
\alias{bayes_summary}
\title{Summarize Bayesian enrichment results}
\usage{
bayes_summary(x, active = FALSE, n = Inf)
}
\arguments{
\item{x}{An \code{enrichResult} object processed by \code{bayes_enrich()}.}

\item{active}{Logical. If \code{TRUE}, keep only rows with \code{bayes_active = TRUE}.}

\item{n}{Number of rows to return. Use \code{Inf} to return all rows.}
}
\value{
A data frame ordered by decreasing \code{posterior}.
}
\description{
Return a data frame sorted by posterior probability from a result processed
by \code{bayes_enrich()}. This is a convenience wrapper around sorting
\code{as.data.frame(x)} by decreasing \code{posterior}.
}
